.stlite-wrapper {
    width: 100%;
    margin: 1em 0;
}

.stlite-frame {
    width: 100%;
    height: 600px;
    border: none;
}

.jupyterlite_sphinx_raw_iframe {
    width: 100%;
}

.jupyterlite_sphinx_iframe_container iframe {
    height: 1000px !important;
}
